@@ -1,4 +1,3 @@
-import distutils.spawn
 import json
 import os
 import pytest
@@ -7,14 +6,9 @@ import subprocess
 import sys
 from semeio.communication import SEMEIOSCRIPT_LOG_FILE
 
-if sys.version_info >= (3, 3):
-    which = shutil.which
-else:
-    which = distutils.spawn.find_executable
-
 
 TEST_DATA_DIR = os.path.join(os.path.dirname(__file__), "test-data")
-ERT_INSTALLED = which("ert") is not None
+ERT_INSTALLED = shutil.which("ert") is not None
 
 
 @pytest.mark.skipif(not ERT_INSTALLED, reason="ERT is not installed")
@@ -32,16 +26,17 @@ def test_semeio_script_integration(tmpdir):
     ert_env["PYTHONPATH"] = os.pathsep.join(map(os.path.realpath, sys.path))
 
     subprocess.check_call(
-        ("ert", "workflow", "TEST_WORKFLOW", "config.ert"), env=ert_env,
+        ("ert", "workflow", "TEST_WORKFLOW", "config.ert"),
+        env=ert_env,
     )
 
     # Assert that data was published correctly
-    with open("storage/reports/TestWorkflowJob/test_data.json") as f:
+    with open("reports/config/TestWorkflowJob/test_data.json") as f:
         reported_data = json.load(f)
-    assert list(range(10)) == reported_data
+    assert [list(range(10))] == reported_data
 
     # Assert that logs were forwarded correctly
-    log_file = os.path.join("storage/reports/TestWorkflowJob/", SEMEIOSCRIPT_LOG_FILE)
+    log_file = os.path.join("reports/config/TestWorkflowJob/", SEMEIOSCRIPT_LOG_FILE)
     with open(log_file) as f:
         log = f.readlines()
     assert len(log) == 1
