@@ -6,10 +6,12 @@ import pytest
 import yaml
 from res.enkf import EnKFMain, ResConfig
 
-from semeio.jobs.scripts.correlated_observations_scaling import (
+from semeio.workflows.correlated_observations_scaling import cos
+from semeio.workflows.correlated_observations_scaling.cos import (
     CorrelatedObservationsScalingJob,
 )
 from tests.jobs.correlated_observations_scaling.conftest import TEST_DATA_DIR
+from ert_shared.plugins.plugin_manager import ErtPluginManager
 
 
 def assert_obs_vector(vector, val_1, index_list=None, val_2=None):
@@ -23,14 +25,6 @@ def assert_obs_vector(vector, val_1, index_list=None, val_2=None):
                 assert node.getStdScaling(index) == val_1
 
 
-def get_job_dir():
-    from semeio import jobs
-
-    head, _ = os.path.split(os.path.abspath(jobs.__file__))
-    return os.path.join(head, "config_workflow_jobs")
-
-
-@pytest.mark.skipif(TEST_DATA_DIR is None, reason="no libres test-data")
 @pytest.mark.usefixtures("setup_ert")
 def test_old_enkf_scaling_job(setup_ert):
     res_config = setup_ert
@@ -47,9 +41,16 @@ def test_old_enkf_scaling_job(setup_ert):
     assert_obs_vector(obs_vector, np.sqrt(4.0 / 2.0))
 
 
-@pytest.mark.skipif(TEST_DATA_DIR is None, reason="no libres test-data")
 @pytest.mark.usefixtures("setup_ert")
 def test_installed_python_version_of_enkf_scaling_job(setup_ert, monkeypatch):
+
+    pm = ErtPluginManager(
+        plugins=[
+            cos,
+        ]
+    )
+    installable_workflow_jobs = pm.get_installable_workflow_jobs()
+
     res_config = setup_ert
     ert = EnKFMain(res_config)
 
@@ -65,7 +66,7 @@ def test_installed_python_version_of_enkf_scaling_job(setup_ert, monkeypatch):
 
     ert.getWorkflowList().addJob(
         "CORRELATE_OBSERVATIONS_SCALING",
-        os.path.join(get_job_dir(), "CORRELATED_OBSERVATIONS_SCALING"),
+        installable_workflow_jobs["CORRELATED_OBSERVATIONS_SCALING"],
     )
 
     job = ert.getWorkflowList().getJob("CORRELATE_OBSERVATIONS_SCALING")
@@ -79,16 +80,18 @@ def test_installed_python_version_of_enkf_scaling_job(setup_ert, monkeypatch):
     job.run(ert, ["job_config.yml"])
 
     assert_obs_vector(
-        obs_vector, np.sqrt(4.0 / 2.0), index_list=[0, 1, 2], val_2=np.sqrt(3.0 / 2.0),
+        obs_vector,
+        np.sqrt(4.0 / 2.0),
+        index_list=[0, 1, 2],
+        val_2=np.sqrt(3.0 / 2.0),
     )
 
 
-@pytest.mark.skipif(TEST_DATA_DIR is None, reason="no libres test-data")
 @pytest.mark.usefixtures("setup_tmpdir")
-def test_compare_different_jobs():
+def test_compare_different_jobs(test_data_root):
     cos_config = {"CALCULATE_KEYS": {"keys": [{"key": "WPR_DIFF_1"}]}}
 
-    test_data_dir = os.path.join(TEST_DATA_DIR, "local", "snake_oil")
+    test_data_dir = os.path.join(test_data_root, "snake_oil")
 
     shutil.copytree(test_data_dir, "test_data")
     os.chdir(os.path.join("test_data"))
@@ -113,15 +116,14 @@ def test_compare_different_jobs():
     assert_obs_vector(obs_vector, np.sqrt(4 / 2))
 
 
-@pytest.mark.skipif(TEST_DATA_DIR is None, reason="no libres test-data")
 @pytest.mark.usefixtures("setup_tmpdir")
-def test_main_entry_point_gen_data():
+def test_main_entry_point_gen_data(test_data_root):
     cos_config = {
         "CALCULATE_KEYS": {"keys": [{"key": "WPR_DIFF_1"}]},
         "UPDATE_KEYS": {"keys": [{"key": "WPR_DIFF_1", "index": [400, 800]}]},
     }
 
-    test_data_dir = os.path.join(TEST_DATA_DIR, "local", "snake_oil")
+    test_data_dir = os.path.join(test_data_root, "snake_oil")
 
     shutil.copytree(test_data_dir, "test_data")
     os.chdir(os.path.join("test_data"))
@@ -141,36 +143,44 @@ def test_main_entry_point_gen_data():
 
     CorrelatedObservationsScalingJob(ert).run(cos_config)
     assert_obs_vector(
-        obs_vector, 1.0, [0, 1], np.sqrt(3.0 / 2.0),
+        obs_vector,
+        1.0,
+        [0, 1],
+        np.sqrt(3.0 / 2.0),
     )
 
-    svd_file = (
-        "storage/snake_oil/ensemble/reports/CorrelatedObservationsScalingJob/svd.json"
-    )
+    svd_file = "reports/snake_oil/CorrelatedObservationsScalingJob/svd.json"
     # Assert that data was published correctly
     with open(svd_file) as f:
-        reported_svd = json.load(f)
+        svd_reports = json.load(f)
+        assert len(svd_reports) == 2
+
+        reported_svd = svd_reports[1]
         assert reported_svd == pytest.approx(
-            (6.531760256452532, 2.0045135017540487, 1.1768827000026516,), 0.1
+            (
+                6.531760256452532,
+                2.0045135017540487,
+                1.1768827000026516,
+            ),
+            0.1,
         )
 
-    scale_file = (
-        "storage/snake_oil/ensemble/reports/"
-        "CorrelatedObservationsScalingJob/scale_factor.json"
-    )
+    scale_file = "reports/snake_oil/CorrelatedObservationsScalingJob/scale_factor.json"
     with open(scale_file) as f:
-        reported_scalefactor = json.load(f)
+        scalefactor_reports = json.load(f)
+        assert len(scalefactor_reports) == 2
+
+        reported_scalefactor = scalefactor_reports[1]
         assert reported_scalefactor == pytest.approx(1.224744871391589, 0.1)
 
 
-@pytest.mark.skipif(TEST_DATA_DIR is None, reason="no libres test-data")
 @pytest.mark.usefixtures("setup_tmpdir")
-def test_main_entry_point_summary_data_calc():
+def test_main_entry_point_summary_data_calc(test_data_root):
     cos_config = {
         "CALCULATE_KEYS": {"keys": [{"key": "WOPR_OP1_108"}, {"key": "WOPR_OP1_144"}]}
     }
 
-    test_data_dir = os.path.join(TEST_DATA_DIR, "local", "snake_oil")
+    test_data_dir = os.path.join(test_data_root, "snake_oil")
 
     shutil.copytree(test_data_dir, "test_data")
     os.chdir(os.path.join("test_data"))
@@ -191,7 +201,7 @@ def test_main_entry_point_summary_data_calc():
         assert node.getStdScaling(index) == np.sqrt(1.0)
 
 
-@pytest.mark.skipif(TEST_DATA_DIR is None, reason="no libres test-data")
+@pytest.mark.skipif(TEST_DATA_DIR is None, reason="no equinor libres test-data")
 @pytest.mark.equinor_test
 @pytest.mark.usefixtures("setup_tmpdir")
 def test_main_entry_point_summary_data_update():
@@ -226,7 +236,7 @@ def test_main_entry_point_summary_data_update():
         assert node.getStdScaling(index) == 1.0
 
 
-@pytest.mark.skipif(TEST_DATA_DIR is None, reason="no libres test-data")
+@pytest.mark.skipif(TEST_DATA_DIR is None, reason="no equinor libres test-data")
 @pytest.mark.equinor_test
 @pytest.mark.usefixtures("setup_tmpdir")
 def test_main_entry_point_block_data_calc():
@@ -252,7 +262,7 @@ def test_main_entry_point_block_data_calc():
         assert node.getStdScaling(index) == 2.0
 
 
-@pytest.mark.skipif(TEST_DATA_DIR is None, reason="no libres test-data")
+@pytest.mark.skipif(TEST_DATA_DIR is None, reason="no equinor libres test-data")
 @pytest.mark.equinor_test
 @pytest.mark.usefixtures("setup_tmpdir")
 def test_main_entry_point_block_and_summary_data_calc():
