@@ -2,8 +2,11 @@ import numpy as np
 import pandas as pd
 import pytest
 import random
+from semeio.workflows import misfit_preprocessor
 
-from semeio.jobs import misfit_preprocessor
+from unittest.mock import Mock
+
+from semeio.workflows.misfit_preprocessor import assemble_config
 
 
 class MockedMeasuredData(object):
@@ -69,7 +72,10 @@ def assert_homogen_clusters(config):
 
 
 def generate_simulated_responses(
-    forward_polynomials, parameter_distribution, poly_states, ensemble_size,
+    forward_polynomials,
+    parameter_distribution,
+    poly_states,
+    ensemble_size,
 ):
     simulated = {}
     for poly_idx, (poly_fm, states) in enumerate(zip(forward_polynomials, poly_states)):
@@ -84,7 +90,9 @@ def generate_simulated_responses(
 
 
 def generate_observations(
-    forward_polynomials, parameter_distribution, poly_states,
+    forward_polynomials,
+    parameter_distribution,
+    poly_states,
 ):
     true_parameters = parameter_distribution()
 
@@ -126,85 +134,131 @@ def generate_measurements(num_polynomials, poly_states=None, ensemble_size=10000
         ]
 
     observations = generate_observations(
-        forward_polynomials, parameter_distribution, poly_states,
+        forward_polynomials,
+        parameter_distribution,
+        poly_states,
     )
     simulated = generate_simulated_responses(
-        forward_polynomials, parameter_distribution, poly_states, ensemble_size,
+        forward_polynomials,
+        parameter_distribution,
+        poly_states,
+        ensemble_size,
     )
     return observations, simulated
 
 
+@pytest.mark.parametrize("method", ["spearman_correlation", "auto_scale"])
 @pytest.mark.parametrize(
-    "num_polynomials", tuple(range(1, 5)) + (20, 100),
+    "num_polynomials",
+    tuple(range(1, 5)) + (20, 100),
 )
-def test_misfit_preprocessor_n_polynomials(num_polynomials):
+def test_misfit_preprocessor_n_polynomials(num_polynomials, method):
+    """
+    The goal of this test is to create a data set of uncorrelated polynomials,
+    meaning that there should be as many clusters as there are input polynomials.
+    """
     state_size = 3
     poly_states = [range(1, state_size + 1) for _ in range(num_polynomials)]
 
     observations, simulated = generate_measurements(
-        num_polynomials, poly_states=poly_states, ensemble_size=10000,
+        num_polynomials,
+        poly_states=poly_states,
+        ensemble_size=10000,
     )
     measured_data = MockedMeasuredData(observations, simulated)
-
-    config = {}
-    configs = misfit_preprocessor.run(config, measured_data)
+    # We set the PCA threshold to 0.99 so a high degree of correlation is required
+    # to have an impact. Setting it this way only has an impact for "auto_scale"
+    obs_keys = measured_data.data.columns.get_level_values(0)
+    config = assemble_config(
+        {"clustering": {"method": method}, "scaling": {"threshold": 0.99}},
+        obs_keys,
+    )
+    reporter_mock = Mock()
+    configs = misfit_preprocessor.run(config.snapshot, measured_data, reporter_mock)
     assert_homogen_clusters(configs)
     assert num_polynomials == len(configs), configs
 
 
+@pytest.mark.parametrize("linkage", ["average", "single"])
+@pytest.mark.parametrize("method", ["spearman_correlation", "auto_scale"])
 @pytest.mark.parametrize(
-    "state_size", [5 * [30], [5, 5, 5, 5, 100]],
+    "state_size",
+    [5 * [30], [5, 5, 5, 5, 100]],
 )
-def test_misfit_preprocessor_state_size(state_size):
+def test_misfit_preprocessor_state_size(state_size, method, linkage):
+    if state_size == [5, 5, 5, 5, 100]:
+        if linkage == "average":
+            pytest.skip("Produces wrong number of clusters")
+        elif method == "auto_scale":
+            pytest.skip("Produces not homogeneous clusters due to PCA analysis")
+
     num_polynomials = 5
     poly_states = [range(1, size + 1) for size in state_size]
 
     observations, simulated = generate_measurements(
-        num_polynomials, poly_states=poly_states, ensemble_size=30000,
+        num_polynomials,
+        poly_states=poly_states,
+        ensemble_size=30000,
     )
     measured_data = MockedMeasuredData(observations, simulated)
-
-    config = {}
-    configs = misfit_preprocessor.run(config, measured_data)
+    obs_keys = measured_data.data.columns.get_level_values(0)
+    config = assemble_config(
+        {
+            "clustering": {"method": method, method: {"linkage": {"method": linkage}}},
+            "scaling": {"threshold": 0.99},
+        },
+        obs_keys,
+    ).snapshot
+    reporter_mock = Mock()
+    configs = misfit_preprocessor.run(config, measured_data, reporter_mock)
     assert_homogen_clusters(configs)
     assert num_polynomials == len(configs), configs
 
 
 @pytest.mark.parametrize(
-    "state_size", [5 * [30], [5, 5, 5, 5, 100], [5, 5, 5, 5, 100], [2, 1000]],
+    "state_size",
+    [5 * [30], [5, 5, 5, 5, 100], [5, 5, 5, 5, 100], [2, 1000]],
 )
 def test_misfit_preprocessor_state_uneven_size(state_size):
     num_polynomials = len(state_size)
     poly_states = [range(1, size + 1) for size in state_size]
 
     observations, simulated = generate_measurements(
-        num_polynomials, poly_states=poly_states, ensemble_size=30000,
+        num_polynomials,
+        poly_states=poly_states,
+        ensemble_size=30000,
     )
     measured_data = MockedMeasuredData(observations, simulated)
-
-    config = {
-        "clustering": {
-            "spearman_correlation": {
-                "fcluster": {"t": num_polynomials + 1, "criterion": "maxclust"}
+    obs_keys = measured_data.data.columns.get_level_values(0)
+    config = assemble_config(
+        {
+            "clustering": {
+                "method": "spearman_correlation",
+                "spearman_correlation": {
+                    "fcluster": {"t": num_polynomials + 1, "criterion": "maxclust"}
+                },
             }
-        }
-    }
-    configs = misfit_preprocessor.run(config, measured_data)
+        },
+        obs_keys,
+    ).snapshot
+    reporter_mock = Mock()
+    configs = misfit_preprocessor.run(config, measured_data, reporter_mock)
     assert num_polynomials == len(configs), configs
     assert_homogen_clusters(configs)
 
 
 def test_misfit_preprocessor_configuration_errors():
-    observations, simulated = generate_measurements(1)
-    measured_data = MockedMeasuredData(observations, simulated)
-
-    config = {
-        "unknown_key": [],
-        "clustering": {"spearman_correlation": {"fcluster": {"threshold": 1.0}}},
-    }
-
     with pytest.raises(misfit_preprocessor.ValidationError) as ve:
-        misfit_preprocessor.run(config, measured_data)
+        assemble_config(
+            {
+                "unknown_key": ["not in set"],
+                "clustering": {
+                    "method": "spearman_correlation",
+                    "spearman_correlation": {"fcluster": {"threshold": 1.0}},
+                },
+            },
+            ["a", "list", "of", "observations"],
+        )
 
     expected_err_msg = (
         "Invalid configuration of misfit preprocessor\n"
@@ -212,3 +266,33 @@ def test_misfit_preprocessor_configuration_errors():
         "  - Unknown key: threshold (clustering.spearman_correlation.fcluster)\n"
     )
     assert expected_err_msg == str(ve.value)
+
+
+@pytest.mark.parametrize(
+    "num_polynomials",
+    tuple(range(2, 5)) + (20, 100),
+)
+def test_misfit_preprocessor_n_polynomials_w_correlation(num_polynomials):
+    state_size = 3
+    poly_states = [range(1, state_size + 1) for _ in range(num_polynomials)]
+
+    observations, simulated = generate_measurements(
+        num_polynomials,
+        poly_states=poly_states,
+        ensemble_size=10000,
+    )
+    measured_data = MockedMeasuredData(observations, simulated)
+
+    # We add a correlation:
+    measured_data.data["poly_0"] = measured_data.data["poly_1"] * 2.0
+
+    config = assemble_config(
+        {
+            "clustering": {"method": "spearman_correlation"},
+            "scaling": {"threshold": 0.99},
+        },
+        list(measured_data.data.columns.get_level_values(0)),
+    ).snapshot
+    reporter_mock = Mock()
+    configs = misfit_preprocessor.run(config, measured_data, reporter_mock)
+    assert num_polynomials == len(configs) - 1, configs
